"use client";

import React, { useState, useEffect } from 'react';
import { FaTimes, FaDownload, FaTelegramPlane } from 'react-icons/fa';

const DownloadPopup: React.FC = () => {
  const [isVisible, setIsVisible] = useState(false);

  useEffect(() => {
    const hasSeenPopup = localStorage.getItem('hasSeenPopup');
    if (!hasSeenPopup) {
      // Check if the site is being viewed in a WebView
      const isInWebView = (): boolean => {
        const userAgent = navigator.userAgent || navigator.vendor;
        
        // Detect Android and iOS WebViews
        const isAndroidWebView =
          /Android/i.test(userAgent) && /wv/.test(userAgent) && !/Chrome/.test(userAgent);
        const isIOSWebView = /iPhone|iPod|iPad/i.test(userAgent) && !/Safari/i.test(userAgent);

        // Additional detection for AppCreator24 or other specific WebView environments
        const isAppCreator24WebView = /AppCreator24/i.test(userAgent);

        return isAndroidWebView || isIOSWebView || isAppCreator24WebView;
      };

      // Show the popup after 15 seconds if it's not in a WebView
      if (!isInWebView()) {
        const timer = setTimeout(() => {
          setIsVisible(true);
        }, 15000); // 15000 milliseconds = 15 seconds

        return () => clearTimeout(timer); // Cleanup the timer if the component is unmounted
      }
    }
  }, []);

  const handleClose = () => {
    setIsVisible(false);
    localStorage.setItem('hasSeenPopup', 'true');
  };

  if (!isVisible) return null;

  return (
    <div className="fixed inset-0 flex items-center justify-center bg-black bg-opacity-70 z-50 backdrop-blur-sm animate-fadeIn">
      <div className="relative bg-gray-900 bg-opacity-50 p-8 rounded-lg shadow-lg text-center text-white max-w-lg mx-auto animate-slideIn backdrop-filter backdrop-blur-lg">
        <button
          onClick={handleClose}
          className="absolute top-4 right-4 text-white text-xl hover:text-red-500 transition duration-300 ease-in-out"
        >
          <FaTimes />
        </button>
        <h2 className="text-3xl font-bold mb-4">Join Our Community</h2>
        <p className="mb-6">
          Hey, welcome! We have a community of movie lovers from around the world who discuss movies and other related stuff. We would be glad if you join us. Also, all updates are dropped there, so join us!
        </p>
        <div className="flex flex-col sm:flex-row justify-center items-center gap-4">
          <a
            href="https://t.me/your_telegram_community_link" // Replace with your actual Telegram community link
            className="inline-flex items-center justify-center px-6 py-3 bg-gradient-to-r from-blue-500 to-blue-700 text-white font-semibold rounded-lg shadow-lg transition duration-300 ease-in-out hover:from-blue-600 hover:to-blue-800 backdrop-blur-md"
          >
            <FaTelegramPlane className="mr-2" /> Join Our Community
          </a>
          <a
            href="https://delgor.com/delgor.apk" // Replace with your actual download link
            className="inline-flex items-center justify-center px-6 py-3 bg-gradient-to-r from-red-500 to-red-700 text-white font-semibold rounded-lg shadow-lg transition duration-300 ease-in-out hover:from-red-600 hover:to-red-800 backdrop-blur-md"
          >
            <FaDownload className="mr-2" /> Download App
          </a>
        </div>
      </div>
    </div>
  );
};

export default DownloadPopup;
